@@ -45,6 +45,14 @@ try:
     from yaml import CSafeLoader as SafeLoader
 except ImportError:
     from yaml import SafeLoader
+try:
+    from yaml import CUnsafeLoader as UnsafeLoader
+except ImportError:
+    try:
+        from yaml import UnsafeLoader
+    except ImportError:
+        # pyyaml < 5.4
+        UnsafeLoader = Loader
 try:
     from yaml import CSafeDumper as SafeDumper
 except ImportError:
@@ -65,6 +73,11 @@ def yaml_safe_load(data):
     return yaml.load(data, Loader=SafeLoader)
 
 
+# handle compatibility for yaml.unsafe_load
+def yaml_unsafe_load(data):
+    return yaml.load(data, Loader=UnsafeLoader)
+
+
 # handle compatibility for yaml.dump
 def yaml_dump(data, *args, **kwargs):
     return yaml.dump(data, *args, Dumper=Dumper, **kwargs)
