@@ -71,11 +71,13 @@ CONTEXT_VARIABLES = [
     "bootz_ramdisk_addr",
     # others
     "boot_character_delay",
+    "boot_retry",
     "bootloader_prompt",
     "console_device",
     "custom_kernel_args",
     "extra_kernel_args",
     "extra_nfsroot_args",
+    "failure_retry",
     "kernel_loglevel",
     "kernel_start_message",
     "lava_test_results_dir",
@@ -85,6 +87,7 @@ CONTEXT_VARIABLES = [
     "tftp_mac_address",
     "uboot_extra_error_message",
     "uboot_needs_interrupt",
+    "uboot_altbank",
 ]
 
 
@@ -148,6 +151,7 @@ def action():
         Optional("timeout"): timeout(),
         Optional("repeat"): Range(min=1),  # TODO: where to put it?
         Optional("failure_retry"): Range(min=1),  # TODO: where to put it?
+        Optional("failure_retry_interval"): Range(min=1),
     }
 
 
@@ -156,6 +160,7 @@ def notify():
         Required("url"): str,
         Optional("method"): Any("GET", "POST"),
         Optional("token"): str,
+        Optional("header"): str,
         Optional("dataset"): Any("minimal", "logs", "results", "all"),
         Optional("content-type"): Any("json", "urlencoded"),
     }
@@ -165,7 +170,8 @@ def notify():
             {
                 Required("status"): Any(
                     "finished", "running", "complete", "canceled", "incomplete"
-                )
+                ),
+                Optional("dependency_query"): str,
             },
             {
                 Required("status"): Any("complete", "incomplete"),
@@ -202,7 +208,6 @@ def extra_checks(data):
     check_multinode_or_environment(data)
     check_multinode_roles(data)
     check_namespace(data)
-    check_secrets_visibility(data)
 
 
 def check_job_timeouts(data):
@@ -282,11 +287,6 @@ def check_namespace(data):
         raise Invalid("When using namespaces, every action should have a namespace")
 
 
-def check_secrets_visibility(data):
-    if "secrets" in data and data["visibility"] == "public":
-        raise Invalid('When using "secrets", visibility shouldn\'t be "public"')
-
-
 def job(extra_context_variables=[]):
     context_variables = CONTEXT_VARIABLES + extra_context_variables
     lava_lxc = {
@@ -312,6 +312,7 @@ def job(extra_context_variables=[]):
                 Optional("actions"): {str: timeout()},
                 Optional("connection"): timeout(),
                 Optional("connections"): {str: timeout()},
+                Optional("queue"): timeout(),
             },
             Required("visibility"): Any("public", "personal", {"group": [str]}),
             Optional("context"): Schema(
@@ -375,10 +376,15 @@ def job(extra_context_variables=[]):
 
 
 docker_image_format = Match(
-    "^[a-z0-9]+[a-z0-9._/-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$",
+    "^[a-z0-9]+[a-z0-9._/:-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$",
     msg="Invalid docker image name",
 )
 
 
 def docker(image_key="image"):
-    return {Required(image_key): docker_image_format, Optional("local"): bool}
+    return {
+        Required(image_key): docker_image_format,
+        Optional("local"): bool,
+        Optional("container_name"): str,
+        Optional("network_from"): str,
+    }
