@@ -43,13 +43,13 @@ def url(extra=None):
         {
             **base_url,
             **extra,
-            Required("format"): Any("cpio.newc", "ext4"),
+            Required("format"): Any("cpio.newc", "ext4", "tar"),
             Optional("partition"): int,
             Required("overlays"): {
                 Optional("lava"): bool,
                 str: {
                     **base_url,
-                    Required("format"): Any("tar"),
+                    Required("format"): Any("file", "tar"),
                     Required("path"): str,
                 },
             },
