@@ -68,11 +68,17 @@ class BootPyOCDRetry(RetryAction):
 
     def populate(self, parameters):
         self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        method_params = self.job.device["actions"]["boot"]["methods"]["pyocd"][
+            "parameters"
+        ]
         if self.job.device.hard_reset_command:
             self.pipeline.add_action(ResetDevice())
             self.pipeline.add_action(WaitDeviceBoardID(self.job.device.get("board_id")))
+        if method_params.get("connect_before_flash", False):
+            self.pipeline.add_action(ConnectDevice())
         self.pipeline.add_action(FlashPyOCDAction())
-        self.pipeline.add_action(ConnectDevice())
+        if not method_params.get("connect_before_flash", False):
+            self.pipeline.add_action(ConnectDevice())
 
 
 class FlashPyOCDAction(Action):
@@ -97,7 +103,20 @@ class FlashPyOCDAction(Action):
         if self.job.device["board_id"] == "0000000000":
             self.errors = "[PYOCD] board_id unset"
         substitutions = {}
-        self.base_command.extend(["--board", self.job.device["board_id"]])
+        # '--uid' should be used with 'pyocd flash' for connecting to
+        # a specific board. 'pyocd flash --board' doesn't work for
+        # selecting board, and the option has been removed since
+        # version v0.32.0.
+        # '--board' should be used for 'pyocd-flashtool' as '--uid'
+        # isn't available for 'pyocd-flashtool'.
+        # Different boards require (or work better) with a particular
+        # version of pyocd. Due to this, we need to maintain support
+        # for both 'pyocd flash' and 'pyocd-flashtool' for the foreseeable
+        # future.
+        connecting_option = "--uid"
+        if pyocd_binary.startswith("pyocd-flashtool"):
+            connecting_option = "--board"
+        self.base_command.extend([connecting_option, self.job.device["board_id"]])
         for action in self.get_namespace_keys("download-action"):
             pyocd_full_command = []
             image_arg = self.get_namespace_data(
@@ -121,11 +140,15 @@ class FlashPyOCDAction(Action):
         if not self.exec_list:
             self.errors = "No PyOCD command to execute"
 
+        pre_os_command = self.job.device.pre_os_command
+        if pre_os_command:
+            self.exec_list.append(pre_os_command.split(" "))
+
     def run(self, connection, max_end_time):
         connection = super().run(connection, max_end_time)
         for pyocd_command in self.exec_list:
             pyocd = " ".join(pyocd_command)
             self.logger.info("PyOCD command: %s", pyocd)
-            if not self.run_command(pyocd.split(" ")):
+            if not self.run_command(pyocd.split(" "), allow_silent=True):
                 raise JobError("%s command failed" % (pyocd.split(" ")))
         return connection
