@@ -19,6 +19,8 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import os
+import subprocess
+import shlex
 from lava_common.constants import DISPATCHER_DOWNLOAD_DIR, SYS_CLASS_KVM
 from lava_common.exceptions import JobError
 from lava_common.utils import debian_package_arch, debian_package_version
@@ -107,12 +109,71 @@ class CallQemuAction(Action):
     def __init__(self):
         super().__init__()
         self.base_sub_command = []
+        self.docker = None
         self.sub_command = []
         self.commands = []
         self.methods = None
         self.nfsrootfs = None
         self.qemu_data = {}
 
+    def get_qemu_pkg_suffix(self, arch):
+        if arch in ["amd64", "x86_64"]:
+            return "x86"
+        if arch in ["arm64", "arm", "armhf", "aarch64"]:
+            return "arm"
+        return ""
+
+    def get_debian_version(self, architecture):
+        pkg_suffix = self.get_qemu_pkg_suffix(architecture)
+        if pkg_suffix == "":
+            return False
+        if "docker" in self.parameters:
+            # We will find it by get_raw_version()
+            return False
+        ver_str = debian_package_version(pkg="qemu-system-%s" % pkg_suffix)
+        arch_str = debian_package_arch(pkg="qemu-system-%s" % pkg_suffix)
+        if ver_str == "":
+            return False
+        self.qemu_data = {
+            "qemu_version": ver_str,
+            "host_arch": arch_str,
+            "job_arch": architecture,
+        }
+        self.logger.info(
+            "qemu-system-%s, installed at version: %s, host architecture: %s",
+            pkg_suffix,
+            ver_str,
+            arch_str,
+        )
+        return True
+
+    def get_raw_version(self, architecture):
+        if "docker" in self.parameters:
+            docker = DockerRun(self.parameters["docker"]["image"])
+            docker.run(
+                *shlex.split("qemu-system-%s --version" % architecture), action=self
+            )
+            return True
+        ver_strs = subprocess.check_output(
+            ("qemu-system-%s" % architecture, "--version")
+        )
+        # line is QEMU emulator version xxxx
+        ver_str = ver_strs.split()[3].decode("utf-8", errors="replace")
+        arch_str = (
+            subprocess.check_output(("uname", "-m"))
+            .strip()
+            .decode("utf-8", errors="replace")
+        )
+        self.qemu_data = {
+            "qemu_version": ver_str,
+            "host_arch": arch_str,
+            "job_arch": architecture,
+        }
+        self.logger.info(
+            "qemu, installed at version: %s, host architecture: %s", ver_str, arch_str
+        )
+        return True
+
     def validate(self):
         super().validate()
 
@@ -129,32 +190,9 @@ class CallQemuAction(Action):
         except KeyError:
             self.errors = "Arch parameter must be set in the context section. Please check the device configuration for available architectures."
             return
-        if architecture in ["amd64", "x86_64"]:
-            ver_str = debian_package_version(pkg="qemu-system-x86")
-            arch_str = debian_package_arch(pkg="qemu-system-x86")
-            self.qemu_data = {
-                "qemu_version": ver_str,
-                "host_arch": arch_str,
-                "job_arch": architecture,
-            }
-            self.logger.info(
-                "qemu-system-x86, installed at version: %s, host architecture: %s",
-                ver_str,
-                arch_str,
-            )
-        if architecture in ["arm64", "arm", "armhf", "aarch64"]:
-            ver_str = debian_package_version(pkg="qemu-system-arm")
-            arch_str = debian_package_arch(pkg="qemu-system-arm")
-            self.qemu_data = {
-                "qemu_version": ver_str,
-                "host_arch": arch_str,
-                "job_arch": architecture,
-            }
-            self.logger.info(
-                "qemu-system-arm, installed at version: %s, host architecture: %s",
-                ver_str,
-                arch_str,
-            )
+
+        if not self.get_debian_version(architecture):
+            self.get_raw_version(architecture)
 
         if self.parameters["method"] in ["qemu", "qemu-nfs"]:
             if "prompts" not in self.parameters:
@@ -170,7 +208,10 @@ class CallQemuAction(Action):
                 self.errors = "Invalid device configuration - missing parameters"
             elif not boot["parameters"]["command"]:
                 self.errors = "No QEMU binary command found - missing context."
-            qemu_binary = which(boot["parameters"]["command"])
+            # if qemu is ran under docker, qemu could not be installed and so which will fail
+            qemu_binary = boot["parameters"]["command"]
+            if "docker" not in self.parameters:
+                qemu_binary = which(qemu_binary)
             self.base_sub_command = [qemu_binary]
             self.base_sub_command.extend(boot["parameters"].get("options", []))
             self.base_sub_command.extend(
@@ -258,6 +299,10 @@ class CallQemuAction(Action):
         guest = self.get_namespace_data(
             action="apply-overlay-guest", label="guest", key="filename"
         )
+        applied = self.get_namespace_data(
+            action="append-overlays", label="guest", key="applied"
+        )
+
         # check for NFS
         if "qemu-nfs" == self.parameters["method"]:
             self.logger.debug("Adding NFS arguments to kernel command line.")
@@ -275,7 +320,7 @@ class CallQemuAction(Action):
             ]
             self.sub_command.append("--append")
             self.sub_command.append('"%s"' % " ".join(append))
-        elif guest:
+        elif guest and not applied:
             self.logger.info("Extending command line for qcow2 test overlay")
             # interface is ide by default in qemu
             interface = self.job.device["actions"]["deploy"]["methods"]["image"][
@@ -311,14 +356,22 @@ class CallQemuAction(Action):
             )
 
         if "docker" in self.parameters:
-            docker = DockerRun.from_parameters(self.parameters["docker"])
+            self.docker = docker = DockerRun.from_parameters(
+                self.parameters["docker"], self.job
+            )
+            docker.name(
+                "lava-docker-qemu-%s-%s-" % (self.job.job_id, self.level),
+                random_suffix=True,
+            )
             docker.interactive()
             docker.tty()
+            if "QEMU_AUDIO_DRV" in os.environ:
+                docker.environment("QEMU_AUDIO_DRV", os.environ["QEMU_AUDIO_DRV"])
             docker.bind_mount(DISPATCHER_DOWNLOAD_DIR)
             docker.add_device("/dev/kvm", skip_missing=True)
-            args = []
-            if "binary" in self.parameters["docker"]:
-                args.append(self.parameters["docker"]["binary"])
+
+            # Use docker.binary if provided and fallback to the qemu default binary
+            args = [self.parameters["docker"].get("binary", self.sub_command[0])]
 
             self.logger.info("Pulling docker image")
             docker.prepare(action=self)
@@ -343,5 +396,10 @@ class CallQemuAction(Action):
         )
         return shell_connection
 
+    def cleanup(self, connection):
+        if self.docker is not None:
+            self.logger.info("Stopping the qemu container %s", self.docker.__name__)
+            self.docker.destroy()
+
 
 # FIXME: implement a QEMU protocol to monitor VM boots
