@@ -39,6 +39,7 @@ from lava_dispatcher.utils.shell import which
 from lava_dispatcher.utils.compression import (
     compress_file,
     cpio,
+    create_tarfile,
     decompress_file,
     untar_file,
     uncpio,
@@ -75,6 +76,13 @@ class ApplyOverlayGuest(Action):
             )
 
     def run(self, connection, max_end_time):
+        applied = self.get_namespace_data(
+            action="append-overlays", label="guest", key="applied"
+        )
+        if applied:
+            self.logger.debug("Overlay already applied")
+            return connection
+
         overlay_file = self.get_namespace_data(
             action="compress-overlay", label="output", key="file"
         )
@@ -86,9 +94,14 @@ class ApplyOverlayGuest(Action):
         self.set_namespace_data(
             action=self.name, label="guest", key="filename", value=guest_file
         )
+        mountpoint = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
+
         blkid = prepare_guestfs(
             guest_file,
             overlay_file,
+            mountpoint,
             self.job.device["actions"]["deploy"]["methods"]["image"]["parameters"][
                 "guest"
             ]["size"],
@@ -612,7 +625,7 @@ class ExtractRamdisk(Action):
 
 class CompressRamdisk(Action):
     """
-     recreate ramdisk, with overlay in place
+    recreate ramdisk, with overlay in place
     """
 
     name = "compress-ramdisk"
@@ -845,8 +858,8 @@ class AppendOverlays(Action):
     summary = "append overlays to an image"
 
     # TODO: list libguestfs supported formats
-    IMAGE_FORMATS = ["cpio.newc", "ext4"]
-    OVERLAY_FORMATS = ["tar"]
+    IMAGE_FORMATS = ["cpio.newc", "ext4", "tar"]
+    OVERLAY_FORMATS = ["file", "tar"]
 
     def __init__(self, key, params):
         super().__init__()
@@ -862,6 +875,9 @@ class AppendOverlays(Action):
             raise JobError("'overlays' is not a dictionary")
         for overlay, params in self.params["overlays"].items():
             if overlay == "lava":
+                self.set_namespace_data(
+                    action=self.name, label="guest", key="applied", value=True
+                )
                 continue
             if params.get("format") not in self.OVERLAY_FORMATS:
                 raise JobError(
@@ -888,11 +904,13 @@ class AppendOverlays(Action):
             except RuntimeError as exc:
                 self.logger.exception(str(exc))
                 raise JobError("Unable to update image %s: %r" % (self.key, str(exc)))
+        elif self.params["format"] == "tar":
+            self.update_tar()
         else:
             raise LAVABug("Unknown format %r" % self.params["format"])
         return connection
 
-    def update_cpio(self):
+    def _update(self, f_uncompress, f_compress):
         image = self.get_namespace_data(
             action="download-action", label=self.key, key="file"
         )
@@ -910,7 +928,7 @@ class AppendOverlays(Action):
             image = decompress_file(image, compression)
         # extract the archive
         self.logger.debug("* extracting %r", image)
-        uncpio(image, tempdir)
+        f_uncompress(image, tempdir)
         os.unlink(image)
 
         # Add overlays
@@ -931,18 +949,32 @@ class AppendOverlays(Action):
                 path = self.params["overlays"][overlay]["path"]
             # Take off initial "/" from path, extract relative to this directory
             extract_path = os.path.join(tempdir, path[1:])
-            self.logger.debug("- %s: %r to %r", label, overlay_image, extract_path)
-            # In the "validate" function, we check that path startswith '/'
-            # and does not contains '..'
-            untar_file(overlay_image, extract_path)
+            if overlay == "lava" or self.params["overlays"][overlay]["format"] == "tar":
+                self.logger.debug(
+                    "- %s: untar %r to %r", label, overlay_image, extract_path
+                )
+                # In the "validate" function, we check that path startswith '/'
+                # and does not contains '..'
+                untar_file(overlay_image, extract_path)
+            else:
+                self.logger.debug(
+                    "- %s: cp %r to %r", label, overlay_image, extract_path
+                )
+                shutil.copy(overlay_image, extract_path)
 
         # Recreating the archive
         self.logger.debug("* archiving %r", image)
-        cpio(tempdir, image)
+        f_compress(tempdir, image)
         if compression and not decompressed:
             self.logger.debug("* compressing (%s)", compression)
             image = compress_file(image, compression)
 
+    def update_cpio(self):
+        self._update(uncpio, cpio)
+
+    def update_tar(self):
+        self._update(untar_file, create_tarfile)
+
     def update_guestfs(self):
         image = self.get_namespace_data(
             action="download-action", label=self.key, key="file"
@@ -978,8 +1010,18 @@ class AppendOverlays(Action):
                 )
                 path = self.params["overlays"][overlay]["path"]
                 compress = None
-            self.logger.debug("- %s: %r to %r", label, overlay_image, path)
-            guest.mkdir_p(path)
-            guest.tar_in(overlay_image, path, compress=compress)
+            if overlay_image:
+                self.logger.debug("- %s: %r to %r", label, overlay_image, path)
+                if (
+                    overlay == "lava"
+                    or self.params["overlays"][overlay]["format"] == "tar"
+                ):
+                    guest.mkdir_p(path)
+                    guest.tar_in(overlay_image, path, compress=compress)
+                else:
+                    guest.mkdir_p(os.path.dirname(path))
+                    guest.upload(overlay_image, path)
+            else:
+                self.logger.warning("- %s: <MISSING> to %r", label, path)
         guest.umount(device)
         guest.shutdown()
