@@ -53,7 +53,7 @@ class Downloads(Deployment):
 class DownloadsAction(DownloadAction):
     name = "downloads"
     description = "Just downloads files"
-    summmary = "downloads files"
+    summary = "downloads files"
 
     def populate(self, parameters):
         self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
@@ -65,7 +65,7 @@ class DownloadsAction(DownloadAction):
                     image,
                     download_dir,
                     params=parameters["images"][image],
-                    uniquify=False,
+                    uniquify=parameters.get("uniquify", False),
                 )
             )
 
@@ -106,18 +106,26 @@ class PostprocessWithDocker(Action):
     def run(self, connection, max_end_time):
         job_id = self.job.job_id
 
-        script = ["#!/bin/sh", "exec 2>&1", "set -ex"] + self.steps
+        script = ["#!/bin/sh", "exec 2>&1", "set -ex"]
+
+        # Export data generated during run of the Pipeline like NFS settings
+        if self.job.device:
+            for key in self.job.device["dynamic_data"]:
+                script.append(
+                    "export %s='%s'" % (key, self.job.device["dynamic_data"][key])
+                )
+
+        script = script + self.steps
         script = "\n".join(script) + "\n"
 
         scriptfile = self.path / "postprocess.sh"
         scriptfile.write_text(script)
         scriptfile.chmod(0o755)
 
-        docker = DockerRun.from_parameters(self.docker_parameters)
+        docker = DockerRun.from_parameters(self.docker_parameters, self.job)
         docker.add_device("/dev/kvm", skip_missing=True)
         docker.bind_mount(self.path, LAVA_DOWNLOADS)
 
-        docker.hostname("lava")
         docker.workdir(LAVA_DOWNLOADS)
 
         docker.run(f"{LAVA_DOWNLOADS}/postprocess.sh", action=self)
