@@ -469,7 +469,7 @@ class UrlRepoAction(RepoAction):
 
         # Add 'url' as an alias to 'repository'. DownloaderAction requires an
         # 'url' key.
-        params = dict(**parameters, url=self.parameters["repository"])
+        params = dict(**self.parameters, url=self.parameters["repository"])
 
         self.download_dir = self.mkdtemp()
         self.action_key = "url_repo"
@@ -1112,7 +1112,7 @@ class TestRunnerAction(TestOverlayAction):
                 runsh.write('echo "<LAVA_SIGNAL_STARTRUN $TESTRUN_ID $UUID>"\n')
             runsh.write("set -x\n")
             steps = testdef.get("run", {}).get("steps", [])
-            for cmd in steps:
+            for cmd in [step for step in steps if step is not None]:
                 if "--cmd" in cmd or "--shell" in cmd:
                     cmd = re.sub(r"\$(\d+)\b", r"\\$\1", cmd)
                 runsh.write("%s\n" % cmd)
