@@ -166,11 +166,45 @@ class DockerTestShell(TestShellAction, GetBoardId, DeviceContainerMappingMixin):
 
         container = "lava-docker-test-shell-%s-%s" % (self.job.job_id, self.level)
 
-        docker = DockerRun.from_parameters(self.parameters["docker"])
+        docker = DockerRun.from_parameters(self.parameters["docker"], self.job)
         docker.prepare()
         docker.bind_mount(os.path.join(location, overlay), "/" + overlay)
 
-        namespace = self.parameters.get("namespace")
+        docker_method_conf = (
+            self.job.device["actions"]
+            .get("test", {})
+            .get("methods", {})
+            .get("docker", {})
+        )
+
+        # Preprocess docker option list, to better support partial
+        # overriding of them via device dict:
+        # 1. Filter out None, to make it easier to template
+        # YAML syntactic lists with Jinja2:
+        # '- {{ some_opt_from_device_dict }}'
+        # (if not default, will be set to None).
+        # 2. Flatten sublists, `- ['--opt1', '--opt2']`.
+        def preproc_opts(opts):
+            res = []
+            for o in opts:
+                if o is None:
+                    continue
+                elif isinstance(o, list):
+                    res += o
+                else:
+                    res.append(o)
+            return res
+
+        if "global_options" in docker_method_conf:
+            docker.add_docker_options(
+                *preproc_opts(docker_method_conf["global_options"])
+            )
+        if "options" in docker_method_conf:
+            docker.add_docker_run_options(*preproc_opts(docker_method_conf["options"]))
+
+        namespace = self.parameters.get(
+            "downloads-namespace", self.parameters.get("namespace")
+        )
         if namespace:
             downloads_dir = pathlib.Path(self.job.tmp_dir) / "downloads" / namespace
             if downloads_dir.exists():
@@ -182,7 +216,6 @@ class DockerTestShell(TestShellAction, GetBoardId, DeviceContainerMappingMixin):
 
         docker.interactive()
         docker.tty()
-        docker.hostname("lava")
         docker.name(container)
         docker.environment("PS1", "docker-test-shell:$ ")
 
@@ -202,7 +235,7 @@ class DockerTestShell(TestShellAction, GetBoardId, DeviceContainerMappingMixin):
             device_info=self.device_info, logger=self.logger, required=False
         )
 
-        docker.wait()
+        docker.wait(shell)
 
         # share all the devices as there isn't a 1:1 relationship between
         # the trigger and actual sharing of the devices
