@@ -19,15 +19,20 @@
 
 import logging
 from pathlib import Path
+import random
 import subprocess
 import time
 
+from lava_common.exceptions import InfrastructureError
+
 
 class DockerRun:
     def __init__(self, image):
         self.image = image
         self.__local__ = False
         self.__name__ = None
+        self.__network__ = None
+        self.__suffix__ = ""
         self.__hostname__ = None
         self.__workdir__ = None
         self.__devices__ = []
@@ -39,17 +44,32 @@ class DockerRun:
         self.__docker_run_options__ = []
 
     @classmethod
-    def from_parameters(cls, params):
+    def from_parameters(cls, params, job):
         image = params["image"]
         run = cls(image)
+        suffix = "-lava-" + str(job.job_id)
+        if "container_name" in params:
+            run.name(params["container_name"] + suffix)
+        run.suffix(suffix)
+        run.network(params.get("network_from", None))
         run.local(params.get("local", False))
         return run
 
     def local(self, local):
         self.__local__ = local
 
-    def name(self, name):
-        self.__name__ = name
+    def name(self, name, random_suffix=False):
+        suffix = ""
+        if random_suffix:
+            CHARS = "01234567890abcdefghijklmnopqrtsuwxyz"
+            suffix = "".join((random.SystemRandom().choice(CHARS) for i in range(10)))
+        self.__name__ = name + suffix
+
+    def network(self, network):
+        self.__network__ = network
+
+    def suffix(self, suffix):
+        self.__suffix__ = suffix
 
     def hostname(self, hostname):
         self.__hostname__ = hostname
@@ -97,6 +117,8 @@ class DockerRun:
             cmd.append("--tty")
         if self.__name__:
             cmd.append(f"--name={self.__name__}")
+        if self.__network__:
+            cmd.append(f"--network=container:{self.__network__}{self.__suffix__}")
         if self.__hostname__:
             cmd.append(f"--hostname={self.__hostname__}")
         if self.__workdir__:
@@ -124,6 +146,8 @@ class DockerRun:
             runner = action.run_cmd
         else:
             runner = subprocess.check_call
+        logger = logging.getLogger("dispatcher")
+        logger.debug("cmd: %s", cmd)
         runner(cmd)
 
     def prepare(self, action=None):
@@ -142,10 +166,14 @@ class DockerRun:
             self.run_cmd(["docker", "pull", self.image], action=action)
         self.__check_image_arch__()
 
-    def wait(self):
+    def wait(self, shell=None):
         delay = 1
         while True:
             try:
+                # If possible, check that docker's shell command didn't exit
+                # yet.
+                if shell and not shell.isalive():
+                    raise InfrastructureError("Docker container unexpectedly exited")
                 subprocess.check_call(
                     ["docker", "inspect", "--format=.", self.__name__],
                     stdout=subprocess.DEVNULL,
@@ -171,11 +199,12 @@ class DockerRun:
                 delay = delay * 2  # exponential backoff
 
     def destroy(self):
-        subprocess.call(
-            ["docker", "rm", "-f", self.__name__],
-            stdout=subprocess.DEVNULL,
-            stderr=subprocess.DEVNULL,
-        )
+        if self.__name__:
+            subprocess.call(
+                ["docker", "rm", "-f", self.__name__],
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+            )
 
     def __check_image_arch__(self):
         host = subprocess.check_output(["arch"], text=True).strip()
