@@ -23,11 +23,14 @@ import pexpect
 from lava_dispatcher.action import Action
 from lava_common.exceptions import TestError, JobError, LAVABug
 from lava_common.constants import (
+    KERNEL_BUG_MSG,
     KERNEL_FREE_UNUSED_MSG,
     KERNEL_FREE_INIT_MSG,
     KERNEL_EXCEPTION_MSG,
     KERNEL_FAULT_MSG,
+    KERNEL_OOPS_MSG,
     KERNEL_PANIC_MSG,
+    KERNEL_WARNING_MSG,
     KERNEL_TRACE_MSG,
     METADATA_MESSAGE_LIMIT,
 )
@@ -56,15 +59,21 @@ class LinuxKernelMessages(Action):
     FAULT = 1
     PANIC = 2
     TRACE = 3
+    WARNING = 4
+    OOPS = 5
+    BUG = 6
     # these can be omitted by InitMessages
-    FREE_UNUSED = 4
-    FREE_INIT = 5
+    FREE_UNUSED = 7
+    FREE_INIT = 8
 
     MESSAGE_CHOICES = (
         (EXCEPTION, KERNEL_EXCEPTION_MSG, "exception"),
         (FAULT, KERNEL_FAULT_MSG, "fault"),
         (PANIC, KERNEL_PANIC_MSG, "panic"),
         (TRACE, KERNEL_TRACE_MSG, "trace"),
+        (WARNING, KERNEL_WARNING_MSG, "warning"),
+        (OOPS, KERNEL_OOPS_MSG, "oops"),
+        (BUG, KERNEL_BUG_MSG, "bug"),
         (FREE_UNUSED, KERNEL_FREE_UNUSED_MSG, "success"),
         (FREE_INIT, KERNEL_FREE_INIT_MSG, "success"),
     )
@@ -145,7 +154,7 @@ class LinuxKernelMessages(Action):
                     "Matched prompt #%s: %s", index, connection.prompt_str[index]
                 )
             message = connection.raw_connection.after
-            if index in [cls.TRACE, cls.EXCEPTION]:
+            if index in [cls.TRACE, cls.EXCEPTION, cls.WARNING, cls.BUG]:
                 res = "fail"
                 if action:
                     action.logger.warning(
