@@ -21,6 +21,7 @@ import io
 import junit_xml
 import tap
 
+import lava_server.compat  # pylint: disable=unused-import
 from lava_scheduler_app.models import (
     Device,
     DeviceType,
@@ -149,9 +150,17 @@ class TestJobViewSet(viewsets.ModelViewSet):
             .visible_by_user(self.request.user)
         )
 
+    def get_permissions(self):
+        if self.action in ["update", "destroy", "partial_update"]:
+            self.permission_classes = [IsSuperUser]
+        return super().get_permissions()
+
     @detail_route(methods=["get"], suffix="junit")
     def junit(self, request, **kwargs):
         suites = []
+        classname_prefix = request.query_params.get("classname_prefix", "")
+        if classname_prefix != "":
+            classname_prefix = str(classname_prefix) + "_"
         for suite in self.get_object().testsuite_set.all().order_by("id"):
             cases = []
             for case in suite.testcase_set.all().order_by("id"):
@@ -167,7 +176,7 @@ class TestJobViewSet(viewsets.ModelViewSet):
                 tc = junit_xml.TestCase(
                     case.name,
                     elapsed_sec=duration,
-                    classname=case.suite.name,
+                    classname="%s%s" % (classname_prefix, case.suite.name),
                     timestamp=case.logged,
                 )
                 if case.result == TestCase.RESULT_FAIL:
@@ -186,7 +195,7 @@ class TestJobViewSet(viewsets.ModelViewSet):
                 cases.append(tc)
             suites.append(junit_xml.TestSuite(suite.name, test_cases=cases))
 
-        data = junit_xml.TestSuite.to_xml_string(suites, encoding="utf-8")
+        data = junit_xml.to_xml_report_string(suites, encoding="utf-8")
         response = HttpResponse(data, content_type="application/xml")
         response["Content-Disposition"] = (
             "attachment; filename=job_%d.xml" % self.get_object().id
@@ -385,6 +394,11 @@ class DeviceViewSet(viewsets.ReadOnlyModelViewSet):
             query = query.exclude(health=Device.HEALTH_RETIRED)
         return query
 
+    def get_permissions(self):
+        if self.action in ["create", "update", "destroy", "partial_update"]:
+            self.permission_classes = [IsSuperUser]
+        return super().get_permissions()
+
 
 class WorkerViewSet(viewsets.ReadOnlyModelViewSet):
     queryset = Worker.objects
