@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-from django.conf.urls import include, url
+from django.conf.urls import include
+from lava_server.compat import url
 
 from lava_rest_app.base.views import LavaObtainAuthToken
 from . import versions
