@@ -22,9 +22,12 @@ import io
 import pathlib
 import voluptuous
 import yaml
+import jinja2
 import lava_common.schemas as schemas
+import lava_common.schemas.test.testdef as testdef
 
 from django.conf import settings
+from django.db import transaction
 from django.http.response import HttpResponse
 from django.http import Http404
 
@@ -37,9 +40,12 @@ from lava_results_app.utils import (
     testcase_export_fields,
 )
 from lava_rest_app.base import views as base_views
+from lava_rest_app.base.pasers import PlainTextParser
 from lava_rest_app import filters
 from lava_scheduler_app.dbutils import testjob_submission
+from lava_scheduler_app.models import TestJob
 from lava_scheduler_app.schema import SubmissionException
+from lava_scheduler_app.views import __set_device_health__
 from lava_server.files import File
 
 from rest_framework import status, viewsets
@@ -51,7 +57,9 @@ from rest_framework.permissions import (
 from rest_framework_extensions.mixins import NestedViewSetMixin
 from rest_framework.response import Response
 from rest_framework.exceptions import ParseError, PermissionDenied, ValidationError
+from rest_framework.permissions import AllowAny
 from rest_framework.utils import formatting
+from rest_framework.parsers import JSONParser, FormParser, MultiPartParser
 from lava_scheduler_app.models import (
     Alias,
     Device,
@@ -81,10 +89,14 @@ class TestJobViewSet(base_views.TestJobViewSet):
 
     * `/jobs/`
 
-    You can alidate the given job definition against the schema validator via POST request on:
+    You can validate the given job definition against the schema validator via POST request on:
 
     * `/jobs/validate/`
 
+    You can validate the given test definition against the schema validator via POST request on:
+
+    * `/jobs/validate_testdef/`
+
     The logs, test results and test suites of a specific TestJob are available at:
 
     * `/jobs/<job_id>/logs/`
@@ -154,7 +166,9 @@ class TestJobViewSet(base_views.TestJobViewSet):
     def metadata(self, request, **kwargs):
         return Response({"metadata": self.get_object().get_metadata_dict()})
 
-    @action(methods=["post"], detail=False, suffix="validate")
+    @action(
+        methods=["post"], detail=False, suffix="validate", permission_classes=[AllowAny]
+    )
     def validate(self, request, **kwargs):
         definition = request.data.get("definition", None)
         strict = request.data.get("strict", False)
@@ -174,6 +188,29 @@ class TestJobViewSet(base_views.TestJobViewSet):
                 {"message": "Job invalid: %s" % exc.msg}, status=status.HTTP_200_OK
             )
 
+    @action(
+        methods=["post"],
+        detail=False,
+        suffix="validate-testdef",
+        permission_classes=[AllowAny],
+    )
+    def validate_testdef(self, request, **kwargs):
+        definition = request.data.get("definition", None)
+        if not definition:
+            raise ValidationError({"definition": "Test definition is required."})
+
+        data = yaml_safe_load(definition)
+        try:
+            testdef.validate(data)
+            return Response(
+                {"message": "Test definition valid."}, status=status.HTTP_200_OK
+            )
+        except voluptuous.MultipleInvalid as exc:
+            return Response(
+                {"message": "Test defnition invalid: %s" % str(exc)},
+                status=status.HTTP_200_OK,
+            )
+
     @action(methods=["post"], detail=True, suffix="resubmit")
     def resubmit(self, request, **kwargs):
         if self.get_object().is_multinode:
@@ -218,7 +255,9 @@ class TestJobViewSet(base_views.TestJobViewSet):
     def cancel(self, request, **kwargs):
         # django-rest-framework handles django's PermissionDenied error
         # automagically
-        self.get_object().cancel(request.user)
+        with transaction.atomic():
+            job = TestJob.objects.select_for_update().get(pk=kwargs["pk"])
+            job.cancel(request.user)
         return Response(
             {"message": "Job cancel signal sent."}, status=status.HTTP_200_OK
         )
@@ -377,6 +416,8 @@ class DeviceTypeViewSet(base_views.DeviceTypeViewSet):
 
 
 class DeviceViewSet(base_views.DeviceViewSet, viewsets.ModelViewSet):
+    parser_classes = [JSONParser, FormParser, MultiPartParser, PlainTextParser]
+
     lookup_value_regex = r"[\_\w0-9.-]+"
     serializer_class = serializers.DeviceSerializer
     filter_class = filters.DeviceFilter
@@ -388,6 +429,25 @@ class DeviceViewSet(base_views.DeviceViewSet, viewsets.ModelViewSet):
         else:
             return serializers.DeviceSerializer
 
+    @detail_route(methods=["post"], suffix="set_health")
+    def set_health(self, request, **kwargs):
+        if not request.user.has_perm("lava_scheduler_app.change_device"):
+            raise PermissionDenied(
+                "Insufficient permissions. Please contact system administrator."
+            )
+        device = self.get_object()
+        reason = request.data.get("reason", None)
+        health = request.data.get("health", None)
+        if health is not None:
+            health = health.upper()
+        response = __set_device_health__(device, request.user, health, reason)
+        if response is None:
+            data = {"message": "OK"}
+            return Response(data, status=status.HTTP_202_ACCEPTED)
+        else:
+            data = {"message": response.content}
+            return Response(data, status=response.status_code)
+
     @detail_route(methods=["get", "post"], suffix="dictionary")
     def dictionary(self, request, **kwargs):
         if request.method == "GET":
@@ -421,7 +481,7 @@ class DeviceViewSet(base_views.DeviceViewSet, viewsets.ModelViewSet):
             return response
 
         elif request.method == "POST":
-            if not request.user.has_perm("lava_scheduler_app.change_device"):
+            if not self.get_object().can_change(request.user):
                 raise PermissionDenied(
                     "Insufficient permissions. Please contact system administrator."
                 )
@@ -442,6 +502,32 @@ class DeviceViewSet(base_views.DeviceViewSet, viewsets.ModelViewSet):
             else:
                 return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
+    @action(
+        methods=["post"], detail=False, suffix="validate", permission_classes=[AllowAny]
+    )
+    def validate(self, request, **kwargs):
+        """
+        Takes a string of a device dictionary to validate if it can be
+        rendered and loaded correctly.
+        """
+        devicedict = request.data
+        if not devicedict:
+            raise ValidationError({"device": "Device dictionary is required."})
+
+        try:
+            template = jinja2.Environment(
+                loader=File("device").loader(), autoescape=False, trim_blocks=True
+            ).from_string(devicedict)
+            yaml_safe_load(template.render())
+            return Response(
+                {"message": "Device dictionary valid."}, status=status.HTTP_200_OK
+            )
+        except Exception as exc:
+            return Response(
+                {"message": "Device dictionary invalid: %s" % str(exc)},
+                status=status.HTTP_200_OK,
+            )
+
 
 class WorkerViewSet(base_views.WorkerViewSet, viewsets.ModelViewSet):
     lookup_value_regex = r"[\_\w0-9.-]+"
