@@ -45,7 +45,7 @@ from django.db.models.fields import Field
 from django.db.models.signals import pre_save
 from django.dispatch import receiver
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils import timezone
 
 from lava_common.compat import yaml_load
@@ -850,7 +850,7 @@ class Query(models.Model):
 
     @classmethod
     def get_queryset(cls, content_type, conditions, limit=None, order_by=["-id"]):
-        """ Return list of QuerySet objects for class 'content_type'.
+        """Return list of QuerySet objects for class 'content_type'.
 
         Be mindful when using this method directly as it does not apply the
         visibility rules.
