@@ -46,11 +46,13 @@ from django.utils.crypto import get_random_string
 from django.urls import reverse
 from django.db import models
 from django.utils import timezone
-from django.utils.translation import ugettext_lazy as _
+from django.utils.html import escape
+from django.utils.translation import gettext_lazy as _
 from django.utils.safestring import mark_safe
 
 from lava_common.compat import yaml_dump, yaml_safe_load, yaml_safe_dump
 from lava_common.decorators import nottest
+from lava_common.timeout import Timeout
 from lava_results_app.utils import export_testcase
 from lava_scheduler_app import utils
 from lava_scheduler_app.logutils import logs_instance
@@ -468,9 +470,6 @@ class Worker(RestrictedObject):
             )
         else:
             self.log_admin_entry(user, "%s → Maintenance" % self.get_health_display())
-        for device in self.device_set.all().select_for_update():
-            device.worker_signal("go_health_maintenance", user, self.state, self.health)
-            device.save()
         self.health = Worker.HEALTH_MAINTENANCE
 
     def go_health_retired(self, user, reason=None):
@@ -672,7 +671,9 @@ class Device(RestrictedObject):
             return self.running_jobs[0]
         except AttributeError:
             try:
-                return self.testjobs.get(~Q(state=TestJob.STATE_FINISHED))
+                return self.testjobs.select_related("submitter").get(
+                    ~Q(state=TestJob.STATE_FINISHED)
+                )
             except TestJob.DoesNotExist:
                 return None
         except IndexError:
@@ -775,6 +776,16 @@ class Device(RestrictedObject):
             pass
 
         elif signal == "go_state_finished":
+            pk = job.pk
+            if job.sub_jobs_list:
+                pk = job.sub_id
+            verbose_name = job._meta.verbose_name.capitalize()
+            job_url = '<a href="%s" title="%s summary">%s</a>' % (
+                job.get_absolute_url(),
+                escape(verbose_name),
+                escape(pk),
+            )
+
             self.state = Device.STATE_IDLE
 
             prev_health_display = self.get_health_display()
@@ -786,7 +797,7 @@ class Device(RestrictedObject):
                         self.log_admin_entry(
                             None,
                             "%s → %s (Looping health-check [%s] failed)"
-                            % (prev_health_display, self.get_health_display(), job.id),
+                            % (prev_health_display, self.get_health_display(), job_url),
                         )
                 elif self.health in [
                     Device.HEALTH_GOOD,
@@ -807,14 +818,19 @@ class Device(RestrictedObject):
                     self.log_admin_entry(
                         None,
                         "%s → %s (health-check [%s] %s)"
-                        % (prev_health_display, self.get_health_display(), job.id, msg),
+                        % (
+                            prev_health_display,
+                            self.get_health_display(),
+                            job_url,
+                            msg,
+                        ),
                     )
             elif infrastructure_error:
                 self.health = Device.HEALTH_UNKNOWN
                 self.log_admin_entry(
                     None,
                     "%s → %s (Infrastructure error after %s)"
-                    % (prev_health_display, self.get_health_display(), job.display_id),
+                    % (prev_health_display, self.get_health_display(), job_url),
                 )
 
         else:
@@ -827,28 +843,14 @@ class Device(RestrictedObject):
             # When leaving retirement, don't cascade the change
             if prev_health == Worker.HEALTH_RETIRED:
                 return
-            # Only update health of devices in maintenance
-            if self.health != Device.HEALTH_MAINTENANCE:
+            # Only update health of devices in good
+            if self.health != Device.HEALTH_GOOD:
                 return
             self.log_admin_entry(
                 user, "%s → Unknown (worker going active)" % self.get_health_display()
             )
             self.health = Device.HEALTH_UNKNOWN
 
-        elif signal == "go_health_maintenance":
-            if self.health in [
-                Device.HEALTH_BAD,
-                Device.HEALTH_MAINTENANCE,
-                Device.HEALTH_RETIRED,
-            ]:
-                return
-            self.log_admin_entry(
-                user,
-                "%s → Maintenance (worker going maintenance)"
-                % self.get_health_display(),
-            )
-            self.health = Device.HEALTH_MAINTENANCE
-
         elif signal == "go_health_retired":
             if self.health in [Device.HEALTH_BAD, Device.HEALTH_RETIRED]:
                 return
@@ -967,6 +969,13 @@ class Device(RestrictedObject):
         except OSError:
             return None
 
+    def cancel_job(self):
+        current_job = self.current_job()
+        if current_job is not None:
+            with transaction.atomic:
+                current_job.go_state_canceling()
+                current_job.save()
+
 
 class JobFailureTag(models.Model):
     """
@@ -1182,6 +1191,11 @@ def _create_pipeline_job(
                     "No known groups were found in the visibility list."
                 )
 
+    # handle queue timeout.
+    queue_timeout = None
+    if "timeouts" in job_data and "queue" in job_data["timeouts"]:
+        queue_timeout = Timeout.parse(job_data["timeouts"]["queue"])
+
     with transaction.atomic():
         job = TestJob(
             definition=yaml_safe_dump(job_data),
@@ -1193,6 +1207,7 @@ def _create_pipeline_job(
             health_check=health_check,
             priority=priority,
             is_public=is_public,
+            queue_timeout=queue_timeout,
         )
         job.save()
 
@@ -1689,6 +1704,10 @@ class TestJob(models.Model):
     # calculated by the master validation process.
     pipeline_compatibility = models.IntegerField(default=0, editable=False)
 
+    queue_timeout = models.BigIntegerField(
+        verbose_name=_("Queue timeout"), null=True, blank=True, editable=False
+    )
+
     @property
     def size_limit(self):
         return settings.LOG_SIZE_LIMIT * 1024 * 1024
@@ -2336,6 +2355,9 @@ class NotificationCallback(models.Model):
     token = models.TextField(
         default=None, null=True, blank=True, verbose_name="Callback token"
     )
+    header = models.CharField(
+        default="Authorization", max_length=64, verbose_name="Header name"
+    )
 
     MINIMAL = 0
     LOGS = 1
@@ -2401,7 +2423,7 @@ class NotificationCallback(models.Model):
             logger.info("Sending request to callback url %s" % self.url)
             headers = {}
             if self.token is not None:
-                headers["Authorization"] = self.token
+                headers[self.header] = self.token
 
             if self.method == NotificationCallback.GET:
                 ret = requests.get(
