@@ -45,6 +45,13 @@ class WorkerSummary:
         return self.limit > 0 and self.busy >= self.limit
 
 
+def filter_devices(q):
+    q = q.filter(state=Device.STATE_IDLE)
+    q = q.filter(worker_host__state=Worker.STATE_ONLINE)
+    q = q.filter(worker_host__health=Worker.HEALTH_ACTIVE)
+    return q
+
+
 def worker_summary():
     query = Worker.objects.all()
     query = query.values("hostname", "job_limit")
@@ -64,9 +71,31 @@ def worker_summary():
     return ret
 
 
+def check_queue_timeout(logger):
+    logger.info("Check queue timeouts:")
+    jobs = TestJob.objects.filter(
+        state=TestJob.STATE_SUBMITTED, queue_timeout__isnull=False
+    )
+    for testjob in jobs:
+        now = timezone.now()
+        queue_timeout_delta = datetime.timedelta(seconds=testjob.queue_timeout)
+        canceling = testjob.submit_time + queue_timeout_delta < now
+        if canceling:
+            logger.debug("  |--> [%d] canceling", testjob.id)
+            if testjob.is_multinode:
+                for job in testjob.sub_jobs_list:
+                    job.go_state_canceling()
+                    job.save()
+            else:
+                testjob.go_state_canceling()
+                testjob.save()
+    logger.info("done")
+
+
 def schedule(logger, available_dt=None):
     available_devices = schedule_health_checks(logger, available_dt)
     schedule_jobs(logger, available_devices)
+    check_queue_timeout(logger)
 
 
 def schedule_health_checks(logger, available_dt=None):
@@ -82,8 +111,7 @@ def schedule_health_checks(logger, available_dt=None):
         if dt.disable_health_check:
             hc_disabled.append(dt.name)
             # Add all devices of that type to the list of available devices
-            devices = dt.device_set.filter(state=Device.STATE_IDLE)
-            devices = devices.filter(worker_host__state=Worker.STATE_ONLINE)
+            devices = filter_devices(dt.device_set)
             devices = devices.filter(
                 health__in=[Device.HEALTH_GOOD, Device.HEALTH_UNKNOWN]
             )
@@ -108,8 +136,7 @@ def schedule_health_checks(logger, available_dt=None):
 
 def schedule_health_checks_for_device_type(logger, dt):
     devices = dt.device_set.select_for_update()
-    devices = devices.filter(state=Device.STATE_IDLE)
-    devices = devices.filter(worker_host__state=Worker.STATE_ONLINE)
+    devices = filter_devices(devices)
     devices = devices.filter(
         health__in=[Device.HEALTH_GOOD, Device.HEALTH_UNKNOWN, Device.HEALTH_LOOPING]
     )
@@ -237,8 +264,7 @@ def schedule_jobs(logger, available_devices):
 
 def schedule_jobs_for_device_type(logger, dt, available_devices):
     devices = dt.device_set.select_for_update()
-    devices = devices.filter(state=Device.STATE_IDLE)
-    devices = devices.filter(worker_host__state=Worker.STATE_ONLINE)
+    devices = filter_devices(devices)
     devices = devices.filter(health__in=[Device.HEALTH_GOOD, Device.HEALTH_UNKNOWN])
     # Add a random sort: with N devices and num(jobs) < N, if we don't sort
     # randomly, the same devices will always be used while the others will
