@@ -298,6 +298,7 @@ def _notify_criteria_schema():
             Required("status"): Any(
                 "running", "complete", "incomplete", "canceled", "finished"
             ),
+            Optional("dependency_query"): str,
             "type": Any("progression", "regression"),
         },
         extra=True,
@@ -391,6 +392,7 @@ def _job_timeout_schema():
             Required("job"): _timeout_schema(),
             Optional("action"): _timeout_schema(),
             Optional("connection"): _timeout_schema(),
+            Optional("queue"): _timeout_schema(),
             Optional("actions"): {All(action_name): _timeout_schema()},
             Optional("connections"): {All(action_name): _timeout_schema()},
         }
@@ -438,8 +440,27 @@ def _device_boot_schema():
     return Schema({Required("connections"): dict, Required("methods"): dict})
 
 
+def _device_test_schema():
+    return Schema(
+        {
+            Optional("methods"): {
+                Optional("docker"): {
+                    Optional("global_options"): list,
+                    Optional("options"): list,
+                }
+            }
+        }
+    )
+
+
 def _device_actions_schema():
-    return Schema({"deploy": _device_deploy_schema(), "boot": _device_boot_schema()})
+    return Schema(
+        {
+            "deploy": _device_deploy_schema(),
+            "boot": _device_boot_schema(),
+            Optional("test"): _device_test_schema(),
+        }
+    )
 
 
 def _device_timeouts_schema():
@@ -464,6 +485,7 @@ def _device_commands_schema():
         {
             All(str): Any(list, dict, str),
             Optional("connections"): _device_connections_commands(),
+            Optional("must_use_connection"): bool,
             Optional("users"): _device_user_commands(),
         }
     )
@@ -501,14 +523,6 @@ _device_schema = Schema(
 )
 
 
-def _validate_secrets(data_object):
-    if "secrets" in data_object:
-        if data_object["visibility"] == "public":
-            raise SubmissionException(
-                "When 'secrets' is used, 'visibility' shouldn't be 'public'"
-            )
-
-
 def _validate_vcs_parameters(data_objects):
     for action in data_objects["actions"]:
         if "test" in action and "definitions" in action["test"]:
@@ -534,7 +548,6 @@ def validate_submission(data_object):
     except MultipleInvalid as exc:
         raise SubmissionException(exc)
 
-    _validate_secrets(data_object)
     _validate_vcs_parameters(data_object)
     _validate_multinode(data_object)
     return True
