@@ -19,6 +19,7 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import random
+from django.conf import settings
 from django.contrib.admin.models import LogEntry
 from django.utils.html import escape, format_html
 from django.utils.safestring import mark_safe
@@ -246,6 +247,21 @@ class JobTable(LavaTable):
         else:
             return ""
 
+    def render_submitter(self, record):
+        user_name = record.submitter.username
+        full_name = record.submitter.get_full_name()
+
+        if settings.SHOW_SUBMITTER_FULL_NAME and full_name:
+            show_text = full_name
+            hover_text = user_name
+        else:
+            show_text = user_name
+            hover_text = full_name if full_name else user_name
+
+        return mark_safe(  # nosec - internal data
+            '<span title="%s">%s</span>' % (hover_text, show_text)
+        )
+
     class Meta(LavaTable.Meta):
         model = TestJob
         # alternatively, use 'fields' value to include specific fields.
@@ -548,7 +564,7 @@ class DeviceHealthTable(LavaTable):
     )
     health = tables.Column()
     last_report_time = tables.DateColumn(
-        verbose_name="last report time", accessor="last_health_report_job.end_time"
+        verbose_name="last report time", accessor="last_health_report_job__end_time"
     )
     last_health_report_job = tables.Column("last report job")
 
@@ -568,6 +584,9 @@ class DeviceTypeTable(LavaTable):
     def render_idle(self, record):
         return record["idle"] if record["idle"] > 0 else ""
 
+    def render_maintenance(self, record):
+        return record["maintenance"] if record["maintenance"] > 0 else ""
+
     def render_offline(self, record):
         return record["offline"] if record["offline"] > 0 else ""
 
@@ -588,6 +607,7 @@ class DeviceTypeTable(LavaTable):
     # the change in the aggregation breaks the accessor.
     name.orderable = False
     idle = tables.Column()
+    maintenance = tables.Column()
     offline = tables.Column()
     busy = tables.Column()
     # sadly, this needs to be not orderable as it would otherwise sort by the accessor.
@@ -762,7 +782,7 @@ class LogEntryTable(LavaTable):
     def render_change_message(self, record):
         message = record.get_change_message()
         if record.is_change():
-            return message
+            return mark_safe(message)
         elif record.is_addition():
             return mark_safe(  # nosec - internal data
                 '<span class="glyphicon glyphicon-plus text-success"></span> %s'
