@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-from django.conf.urls import url
+from lava_server.compat import url
 from lava_scheduler_app.views import (
     active_device_list,
     active_jobs,
@@ -67,6 +67,9 @@ from lava_scheduler_app.views import (
     multinode_job_definition_plain,
     mydevice_list,
     myjobs,
+    my_active_jobs,
+    my_queued_jobs,
+    my_error_jobs,
     online_device_list,
     passing_health_checks,
     queue,
@@ -215,6 +218,9 @@ urlpatterns = [
         name="lava.scheduler.job.fetch_data",
     ),
     url(r"^myjobs$", myjobs, name="lava.scheduler.myjobs"),
+    url(r"^myactivejobs$", my_active_jobs, name="lava.scheduler.myjobs.active"),
+    url(r"^myqueuedjobs$", my_queued_jobs, name="lava.scheduler.myjobs.queued"),
+    url(r"^myerrorjobs$", my_error_jobs, name="lava.scheduler.myjobs.error"),
     url(r"^favorite-jobs$", favorite_jobs, name="lava.scheduler.favorite_jobs"),
     url(
         r"^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/priority$",
