@@ -22,12 +22,20 @@ from django.utils.version import get_version
 from django.core.management.base import CommandParser
 from rest_framework_extensions import __version__ as DRFE_VERSION_STR
 import rest_framework_filters as filters
+import junit_xml
 
 
 DJANGO_VERSION = get_version()
 DRFE_VERSION = [int(n) for n in DRFE_VERSION_STR.split(".")]
 
 
+try:
+    # pylint: disable=unused-import
+    from django.urls import re_path as url  # noqa
+except ImportError:
+    # pylint: disable=unused-import
+    from django.conf.urls import url  # noqa
+
 # Handles compatibility for django_restframework_filters
 try:
     from rest_framework_filters.backends import RestFrameworkFilterBackend  # noqa
@@ -47,6 +55,10 @@ except ImportError:
         return filters.RelatedFilter(cls, name=name, queryset=queryset)
 
 
+if not getattr(junit_xml, "to_xml_report_string", None):
+    junit_xml.to_xml_report_string = junit_xml.TestSuite.to_xml_string
+
+
 FilterBackend = RestFrameworkFilterBackend
 
 
@@ -220,3 +232,7 @@ except ImportError:
 
     def djt2_paginator_class():
         return {"klass": LazyPaginator}
+
+
+def is_ajax(request):
+    return request.META.get("HTTP_X_REQUESTED_WITH") == "XMLHttpRequest"
