@@ -25,9 +25,19 @@ from django.core.management.base import BaseCommand
 from django.db.models import IntegerField, Case, When, Count, Q
 
 from lava_common.compat import yaml_safe_load
+from lava_common.exceptions import PermissionNameError
 from lava_server.files import File
 import lava_scheduler_app.environment as environment
-from lava_scheduler_app.models import Alias, Device, DeviceType, Tag, Worker
+from lava_scheduler_app.models import (
+    Alias,
+    Device,
+    DeviceType,
+    Group,
+    GroupDevicePermission,
+    Tag,
+    User,
+    Worker,
+)
 
 
 class Command(BaseCommand):
@@ -40,7 +50,12 @@ class Command(BaseCommand):
         if hasattr(sync_dict, "items"):
             for pair in sync_dict.items:
                 if isinstance(pair.value, jinja2.nodes.List):
-                    ret[pair.key.value] = [node.value for node in pair.value.items]
+                    ret[pair.key.value] = [
+                        [sub_node.value for sub_node in node.items]
+                        if isinstance(node, jinja2.nodes.List)
+                        else node.value
+                        for node in pair.value.items
+                    ]
                 elif isinstance(pair.value, jinja2.nodes.Const):
                     ret[pair.key.value] = pair.value.value
                 else:  # Ignore all other nodes
@@ -62,15 +77,15 @@ class Command(BaseCommand):
         # Fetches value of the 'sync_to_lava' variable set in dictionary.
         try:
             config = self._parse_config(hostname)
-        except (OSError, jinja2.TemplateError):
-            return None
+        except (OSError, jinja2.TemplateError) as exc:
+            return None, exc
 
         sync = list(config.find_all(jinja2.nodes.Assign))
         for node in sync:
             with contextlib.suppress(AttributeError):
                 if node.target.name == self.SYNC_KEY:
-                    return node.node
-        return None
+                    return node.node, None
+        return None, None
 
     def handle(self, *_, **options):
         dicts = File("device").list("*.jinja2")
@@ -80,11 +95,19 @@ class Command(BaseCommand):
             hostname = name.rsplit(".", 1)[0]
 
             # Get value of 'sync_to_lava' variable from template.
-            sync_dict = self._get_sync_to_lava(hostname)
+            sync_dict, exc = self._get_sync_to_lava(hostname)
+
+            if exc:
+                self.stdout.write(f"* {hostname} [SKIP]")
+                self.stdout.write(f"  -> invalid jinja2 template")
+                self.stdout.write(f"  -> {exc}")
+                continue
+
             if sync_dict is None:
                 self.stdout.write(f"* {hostname} [SKIP]")
                 self.stdout.write(f"  -> missing '{self.SYNC_KEY}'")
                 continue
+
             # Convert it to dictionary.
             sync_dict = self._parse_sync_dict(sync_dict)
 
@@ -163,6 +186,67 @@ class Command(BaseCommand):
                 device.tags.add(tag)
                 self.stdout.write(f"  -> tag: {tag_name}")
 
+            # Link physical owner
+            specified_owner = sync_dict.get("physical_owner", "")
+            try:
+                physical_owner = User.objects.get(username=specified_owner)
+                device.physical_owner = physical_owner
+                self.stdout.write(f"  -> user: {specified_owner}")
+            except User.DoesNotExist:
+                device.physical_owner = None
+                if specified_owner:
+                    self.stdout.write(f"  -> user '{specified_owner}' does not exist")
+            finally:
+                device.save()
+
+            # Link physical group
+            specified_group = sync_dict.get("physical_group", "")
+            try:
+                physical_group = Group.objects.get(name=specified_group)
+                device.physical_group = physical_group
+                self.stdout.write(f"  -> group: {specified_group}")
+            except Group.DoesNotExist:
+                device.physical_group = None
+                if specified_group:
+                    self.stdout.write(f"  -> group '{specified_group}' does not exist")
+            finally:
+                device.save()
+
+            # Assign permission
+            specified_permissions = sync_dict.get("group_device_permissions", [])
+            for permission in specified_permissions:
+                perm = permission[0]
+                group = permission[1]
+
+                try:
+                    permission_group = Group.objects.get(name=group)
+                    try:
+                        GroupDevicePermission.objects.assign_perm(
+                            perm, permission_group, device
+                        )
+                        self.stdout.write(
+                            f"  -> add group permission: ({perm}, {group})"
+                        )
+                    except PermissionNameError:
+                        self.stdout.write(f"  -> permission '{perm}' does not exist")
+                except Group.DoesNotExist:
+                    self.stdout.write(f"  -> group '{group}' does not exist")
+
+            # Delete unused permission
+            kwargs = {"device": device}
+            obj_perm = GroupDevicePermission.objects.filter(**kwargs)
+            for perm in obj_perm:
+                if [
+                    perm.permission.codename,
+                    perm.group.name,
+                ] not in specified_permissions:
+                    GroupDevicePermission.objects.remove_perm(
+                        perm.permission.codename, perm.group, perm.device
+                    )
+                    self.stdout.write(
+                        f"  -> delete group permission: ({perm.permission.codename}, {perm.group.name})"
+                    )
+
         # devices which have is_synced true if there's no device dict for them.
         Device.objects.filter(is_synced=True).exclude(
             hostname__in=synced_devices
@@ -170,19 +254,36 @@ class Command(BaseCommand):
 
         # Device types which have all the devices synced and all of them retired
         # should become invisible.
-        dts = (
-            DeviceType.objects.annotate(
-                not_synced_retired_count=Count(
-                    Case(
-                        When(
-                            Q(device__is_synced=False)
-                            | ~Q(device__health=Device.HEALTH_RETIRED),
-                            then=1,
-                        ),
-                        output_field=IntegerField(),
-                    )
+        synced_retired_queryset = DeviceType.objects.annotate(
+            not_synced_retired_count=Count(
+                Case(
+                    When(
+                        Q(device__is_synced=False)
+                        | ~Q(device__health=Device.HEALTH_RETIRED),
+                        then=1,
+                    ),
+                    output_field=IntegerField(),
                 )
             )
-            .filter(not_synced_retired_count=0)
-            .update(display=False)
         )
+        synced_retired_queryset.filter(not_synced_retired_count=0).update(display=False)
+
+        # Device types which have all the devices synced and some of them not
+        # retired should become visible.
+        synced_not_retired_queryset = DeviceType.objects.annotate(
+            not_synced=Count(
+                Case(
+                    When(Q(device__is_synced=False), then=1),
+                    output_field=IntegerField(),
+                )
+            ),
+            not_retired=Count(
+                Case(
+                    When(~Q(device__health=Device.HEALTH_RETIRED), then=1),
+                    output_field=IntegerField(),
+                )
+            ),
+        )
+        synced_not_retired_queryset.filter(not_synced=0).filter(
+            not_retired__gt=0
+        ).update(display=True)
