@@ -19,13 +19,21 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
+from yaml import YAMLError
 import contextlib
-import imp
+import importlib
 import re
 
-from django.conf.global_settings import *
+from django.core.exceptions import ImproperlyConfigured
+
+# pylint: disable=unused-import
+from django.conf.global_settings import DISALLOWED_USER_AGENTS
+
+# pylint: disable=unused-import
+from django.conf.global_settings import INTERNAL_IPS
 
 from lava_common.version import __version__
+from lava_common.compat import yaml_safe_load
 from lava_rest_app.versions import versions as REST_VERSIONS
 from lava_scheduler_app.settings import *
 
@@ -155,11 +163,18 @@ CSRF_COOKIE_HTTPONLY = True
 X_FRAME_OPTIONS = "DENY"
 HTTPS_XML_RPC = True
 
+DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
 
 ########################
 # LAVA custom settings #
 ########################
 
+# Allow mismatch between master and worker versions
+ALLOW_VERSION_MISMATCH = False
+
+# Show submitter full name in job page
+SHOW_SUBMITTER_FULL_NAME = False
+
 # LOG_SIZE_LIMIT in megabytes
 LOG_SIZE_LIMIT = 5
 
@@ -208,6 +223,13 @@ AUTH_LDAP_USER_SEARCH = None
 AUTH_LDAP_GROUP_SEARCH = None
 AUTH_LDAP_GROUP_TYPE = None
 
+# Social accounts support
+AUTH_SOCIALACCOUNT = None
+
+# Gitlab support
+AUTH_GITLAB_URL = None
+AUTH_GITLAB_SCOPE = ["read_user"]
+
 # Debian SSO is of be default
 AUTH_DEBIAN_SSO = None
 
@@ -217,6 +239,9 @@ ALLOW_ADMIN_DELETE = True
 # Default callback http timeout in seconds
 CALLBACK_TIMEOUT = 5
 
+# Default statement timeout in milliseconds
+STATEMENT_TIMEOUT = 30000
+
 # Default length value for all tables
 DEFAULT_TABLE_LENGTH = 25
 
@@ -277,6 +302,9 @@ REST_FRAMEWORK = {
         "rest_framework.authentication.SessionAuthentication",
         "lava_rest_app.authentication.LavaTokenAuthentication",
     ),
+    "DEFAULT_PERMISSION_CLASSES": [
+        "rest_framework.permissions.IsAuthenticatedOrReadOnly"
+    ],
 }
 
 
@@ -287,7 +315,7 @@ REST_FRAMEWORK = {
 # Automatically install some applications
 for module_name in ["devserver", "django_extensions", "django_openid_auth"]:
     with contextlib.suppress(ImportError):
-        imp.find_module(module_name)
+        importlib.import_module(module_name)
         INSTALLED_APPS.append(module_name)
 
 ###########
@@ -303,6 +331,9 @@ def update(values):
     AUTH_LDAP_SERVER_URI = values.get("AUTH_LDAP_SERVER_URI")
     AUTH_LDAP_USER_SEARCH = values.get("AUTH_LDAP_USER_SEARCH")
     AUTH_DEBIAN_SSO = values.get("AUTH_DEBIAN_SSO")
+    AUTH_SOCIALACCOUNT = values.get("AUTH_SOCIALACCOUNT")
+    AUTH_GITLAB_URL = values.get("AUTH_GITLAB_URL")
+    AUTH_GITLAB_SCOPE = values.get("AUTH_GITLAB_SCOPE")
     AUTHENTICATION_BACKENDS = values.get("AUTHENTICATION_BACKENDS")
     DISALLOWED_USER_AGENTS = values.get("DISALLOWED_USER_AGENTS")
     DJANGO_LOGFILE = values.get("DJANGO_LOGFILE")
@@ -313,6 +344,7 @@ def update(values):
     MIDDLEWARE = values.get("MIDDLEWARE")
     MOUNT_POINT = values.get("MOUNT_POINT")
     SENTRY_DSN = values.get("SENTRY_DSN")
+    STATEMENT_TIMEOUT = values.get("STATEMENT_TIMEOUT")
     USE_DEBUG_TOOLBAR = values.get("USE_DEBUG_TOOLBAR")
 
     # Fix mount point
@@ -332,6 +364,40 @@ def update(values):
     ADMINS = [tuple(v) for v in ADMINS]
     MANAGERS = [tuple(v) for v in MANAGERS]
 
+    # Social accounts authentication config
+    if AUTH_SOCIALACCOUNT or AUTH_GITLAB_URL:
+        auth_socialaccount = {}
+        if AUTH_SOCIALACCOUNT:
+            try:
+                auth_socialaccount = yaml_safe_load(AUTH_SOCIALACCOUNT)
+                if not isinstance(auth_socialaccount, dict):
+                    auth_socialaccount = {}
+            except YAMLError:
+                raise ImproperlyConfigured(
+                    "Failed to load social account configuration."
+                )
+
+        if (
+            AUTH_GITLAB_URL
+        ):  # former GitLab authentication config takes precedence over new approach
+            auth_socialaccount["gitlab"] = {
+                "GITLAB_URL": AUTH_GITLAB_URL,
+                "SCOPE": AUTH_GITLAB_SCOPE,
+            }
+
+        if auth_socialaccount:
+            INSTALLED_APPS.append("allauth")
+            INSTALLED_APPS.append("allauth.account")
+            INSTALLED_APPS.append("allauth.socialaccount")
+
+            for provider in auth_socialaccount.keys():
+                INSTALLED_APPS.append(f"allauth.socialaccount.providers.{provider}")
+
+            AUTHENTICATION_BACKENDS.append(
+                "allauth.account.auth_backends.AuthenticationBackend"
+            )
+            SOCIALACCOUNT_PROVIDERS = auth_socialaccount
+
     # LDAP authentication config
     if AUTH_LDAP_SERVER_URI:
         INSTALLED_APPS.append("ldap")
