@@ -30,7 +30,7 @@ from django.http import (
 )
 from django.shortcuts import render
 from django.template import loader
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.csrf import requires_csrf_token
 from django.views.decorators.http import require_POST
 
