@@ -71,7 +71,9 @@ def pass_device_lxc(mocker):
 def test_simple_share_device_with_container(mocker, pass_device_lxc, device_links):
     add_device_container_mapping("1", {"serial_number": "1234567890"}, "mycontainer")
     share_device_with_container(Namespace(device="foo/bar", serial_number="1234567890"))
-    pass_device_lxc.assert_called_once_with("mycontainer", "/dev/foo/bar", device_links)
+    pass_device_lxc.assert_called_once_with(
+        "mycontainer", "/dev/foo/bar", device_links, "1"
+    )
 
 
 def test_mapping_with_serial_number_but_called_with_vendor_product_id_too(
@@ -96,7 +98,9 @@ def test_mapping_with_serial_number_but_called_with_vendor_product_id_too(
         )
     )
 
-    pass_device_lxc.assert_called_once_with("mycontainer", "/dev/foo/bar", device_links)
+    pass_device_lxc.assert_called_once_with(
+        "mycontainer", "/dev/foo/bar", device_links, "1"
+    )
 
 
 def test_two_concurrent_jobs(mocker, pass_device_lxc, device_links):
@@ -104,7 +108,9 @@ def test_two_concurrent_jobs(mocker, pass_device_lxc, device_links):
     add_device_container_mapping("2", {"serial_number": "9876543210"}, "container2")
     share_device_with_container(Namespace(device="baz/qux", serial_number="9876543210"))
 
-    pass_device_lxc.assert_called_once_with("container2", "/dev/baz/qux", device_links)
+    pass_device_lxc.assert_called_once_with(
+        "container2", "/dev/baz/qux", device_links, "2"
+    )
 
 
 def test_no_device_found(mocker):
@@ -128,7 +134,7 @@ def test_map_by_vendor_id_and_product_id(mocker, pass_device_lxc, device_links):
         )
     )
     pass_device_lxc.assert_called_once_with(
-        "container1", "/dev/bus/usb/001/099", device_links
+        "container1", "/dev/bus/usb/001/099", device_links, "1"
     )
 
 
@@ -159,7 +165,7 @@ def test_only_adds_slash_dev_if_needed(mocker):
     share_device_with_container(
         Namespace(device="/dev/foo/bar", serial_number="1234567890")
     )
-    share.assert_called_once_with("mycontainer", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer", "/dev/foo/bar", job_id="1")
 
 
 def test_second_mapping_does_not_invalidate_first(mocker):
@@ -169,7 +175,7 @@ def test_second_mapping_does_not_invalidate_first(mocker):
     share_device_with_container(
         Namespace(device="/dev/foo/bar", serial_number="1234567890")
     )
-    share.assert_called_once_with("mycontainer1", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer1", "/dev/foo/bar", job_id="1")
 
 
 def test_two_devices_two_containers(mocker):
@@ -179,13 +185,13 @@ def test_two_devices_two_containers(mocker):
     share_device_with_container(
         Namespace(device="/dev/foo/bar", serial_number="1234567890")
     )
-    share.assert_called_once_with("mycontainer1", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer1", "/dev/foo/bar", job_id="1")
     share.reset_mock()
 
     share_device_with_container(
         Namespace(device="/dev/foo/bar", serial_number="badbeeb00c")
     )
-    share.assert_called_once_with("mycontainer2", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer2", "/dev/foo/bar", job_id="1")
 
 
 def test_device_plus_parent(mocker):
@@ -214,13 +220,13 @@ def test_device_plus_parent(mocker):
     share_device_with_container(
         Namespace(device="/dev/foo/bar", serial_number="1234567890")
     )
-    share.assert_called_once_with("mycontainer1", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer1", "/dev/foo/bar", job_id="1")
     share.reset_mock()
 
     share_device_with_container(
         Namespace(device="/dev/foo/bar", vendor_id="1234", product_id="3456")
     )
-    share.assert_called_once_with("mycontainer2", "/dev/foo/bar")
+    share.assert_called_once_with("mycontainer2", "/dev/foo/bar", job_id="1")
     share.reset_mock()
 
 
